pub struct SessionStore { /* private fields */ }Expand description
Session store with automatic lazy eviction of expired sessions
Performs periodic cleanup of expired sessions to prevent unbounded memory growth. Cleanup runs automatically when the session count exceeds a configurable threshold.
Implementations
Sourceimpl SessionStore
impl SessionStore
Sourcepub fn get(&self, id: &str) -> Option<SessionData>
pub fn get(&self, id: &str) -> Option<SessionData>
Get a session
Sourcepub fn save(&self, session: SessionData)
pub fn save(&self, session: SessionData)
Save a session, with automatic cleanup when threshold is exceeded